{% load wagtailcore_tags %}

<a href="{{self.downloadable_file.url}}" download="{{self.downloadable_file.url}}"
    {% if settings.cjkcms.AnalyticsSettings.ga_track_button_clicks %}
        data-ga-event-category='{{self.settings.ga_tracking_event_category|default:"Download"}}'
        data-ga-event-label='{{self.settings.ga_tracking_event_label|default:self.button_title}}'
    {% endif %}
    title="{{ self.alt_text|safe }}"
    class='btn {{ self.button_style }} {{ self.button_size }} {{ self.settings.custom_css_class }}'
    {% if self.settings.custom_id %}id="{{ self.settings.custom_id }}"{% endif %}>
{% if self.button_title %}
    {{ self.button_title|safe }}
{% else %}
    Download {{ self.downloadable_file.title }}
{% endif %}
</a>

{% if self.automatic_download %}
<script>
    $(document).ready(function(){
        window.open("{{self.downloadable_file.url}}", '_blank');
    });
</script>
{% endif %}