{% load i18n %}
<div style="overflow:hidden;width:0;height:0;" aria-hidden="true">
    <label for="cms-decoy-comments">{% trans 'Leave this blank if you are a human' %}</label>
    <textarea rows="1" name="cms-decoy-comments" id="cms-decoy-comments"></textarea>
</div>