# Generated by Django 4.0.7 on 2022-08-13 15:17

import cjkcms.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cjkcms', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='articleindexpage',
            name='body',
            field=cjkcms.fields.CjkcmsStreamField(blank=True, null=True, use_json_field=True),
        ),
        migrations.AlterField(
            model_name='articlepage',
            name='body',
            field=cjkcms.fields.CjkcmsStreamField(blank=True, null=True, use_json_field=True),
        ),
        migrations.AlterField(
            model_name='webpage',
            name='body',
            field=cjkcms.fields.CjkcmsStreamField(blank=True, null=True, use_json_field=True),
        ),
    ]
