{% extends "cjkcms/blocks/grid_block.html" %}
{% load wagtailcore_tags %}

{% block grid_content %}
<div class="card-zero {{self.settings.custom_css_class}}">
      {% for block in self.content %}
            {% include_block block %}
      {% endfor %}
</div>
{% endblock %}
