{% load wagtailcore_tags %}
{
    'en': {
        consent_modal: {
            title: 'We use cookies!',
            description: 'This website uses essential cookies to ensure its proper operation and tracking cookies to understand how you interact with it. The latter will be set only after consent. <button type="button" data-cc="c-settings" class="cc-link">Let me choose</button>',
            primary_btn: {
                text: 'Accept all',
                role: 'accept_all'
            },
            secondary_btn: {
            {% if settings.cookie_consent_deny_btn %}
                text: 'Accept necessary',
                role: 'accept_necessary'
            {% else %}
                text: 'Settings',
                role: 'settings'
            {% endif %}
            }
        },
        settings_modal: {
            title: 'Cookie preferences',
            save_settings_btn: 'Save settings',
            accept_all_btn: 'Accept all',
            reject_all_btn: 'Reject all',
            close_btn_label: 'Close',
            cookie_table_headers: [
                {col1: 'Name'},
                {col2: 'Domain'},
                {col3: 'Expiration'},
                {col4: 'Description'}
            ],
            blocks: [
                {
                    title: 'We value your privacy',
                    description: 'We use cookies to ensure the basic functionalities of the website and to enhance your online experience. You can choose for each category to opt-in/out. {% if settings.privacy_page %} For more details relative to cookies and other sensitive data, please read our <a href="{% pageurl settings.privacy_page %}" class="cc-link">privacy policy</a>.{% endif %}'
                }, {
                    title: 'Strictly necessary cookies',
                    description: 'These cookies are essential for the proper functioning of the website. Without these cookies, the website would not work properly',
                    toggle: {
                        value: 'necessary',
                        enabled: true,
                        readonly: true          // cookie categories with readonly=true are all treated as "necessary cookies"
                    }
                }, {
                    title: 'Performance and Analytics cookies',
                    description: 'These cookies allow the website to remember the choices you have made in the past',
                    toggle: {
                        value: 'analytics',     // your cookie category
                        enabled: false,
                        readonly: false
                    },
                    cookie_table: [             // list of all expected cookies
                        {
                            col1: '^_ga',       // match all cookies starting with "_ga"
                            col2: 'google.com',
                            col3: '2 years',
                            col4: 'Used to distinguish users',
                            is_regex: true
                        },
                        {
                            col1: '_gid',
                            col2: 'google.com',
                            col3: '1 day',
                            col4: 'Used to distinguish users',
                        }
                    ]
                }{% if settings.contact_page %}, {
                    title: 'More information',
                    description: 'For any queries in relation to our policy on cookies and your choices, please <a class="cc-link" href="{% pageurl settings.contact_page %}">contact us</a>.',
                }{% endif %}
            ]
        }
    }
}