{% load wagtailadmin_tags wagtailcore_tags %}

<div class="{{ classname }} collapsed c-sf-container {% if wagtail_version < 5  %}cjkcms-collapsible4{% else %}cjkcms-collapsible{% endif %}">
    <button type="button" class="button button-small">
      <i class="icon icon-fa-cog" aria-hidden="true"></i> Advanced Settings
    </button>
    <div class="cjkcms-collapsible-target" style="display:none;">
      {% for child in children.values %}
      <div class="field {% if child.block.required %}required{% endif %}" data-contentpath="{{ child.block.name }}">
        {% if child.block.label %}
        <label class="field__label" {% if child.id_for_label %}for="{{ child.id_for_label }}"{% endif %}>{{ child.block.label }}</label>
        {% endif %}
        {{ child.render_form }}
      </div>
      {% endfor %}
    </div>
  </div>
  

