{% load wagtailcore_tags cjkcms_tags %}
<footer>

{% get_footers as footers %}
{% for footer in footers %}
    <div {% if footer.custom_id %} id="{{footer.custom_id}}"{% endif %} {% if footer.custom_css_class %} class="{{footer.custom_css_class}}"{% endif %}>
        {% for item in footer.content %}
            {% include_block item with format=format settings=settings %}
        {% endfor %}
    </div>
{% endfor %}

</footer>