# Generated by Django 4.1.8 on 2023-04-16 16:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cjkcms", "0006_analyticssettings_consent_modal_layout_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="bootstrap_icons",
            field=models.BooleanField(
                default=False,
                help_text="Load bootstrap icons css from local/static folder",
                verbose_name="Bootstrap Icons CSS",
            ),
        ),
    ]
